DynRuntime

Struct DynRuntime 

pub struct DynRuntime<T: UserEvent> { /* private fields */ }
A type-erased Runtime.

The concrete runtime is selected through its RuntimeInitAttrs, see DynRuntimeInitAttrs::new.

Implementations

Source

impl<T: UserEvent> DynRuntime<T>

pub fn from_runtime<R: Runtime<T>>(runtime: R) -> Self

Wraps an already initialized runtime.

Prefer Runtime::new with DynRuntimeInitAttrs to let the runtime be initialized with the application’s RuntimeInitArgs; this is only useful for runtimes created by other means.

pub fn is<R: Runtime<T>>(&self) -> bool

Whether the wrapped runtime is of type R.

pub fn downcast_ref<R: Runtime<T>>(&self) -> Option<&R>

Returns a reference to the wrapped runtime if it is of type R.

pub fn downcast_mut<R: Runtime<T>>(&mut self) -> Option<&mut R>

Returns a mutable reference to the wrapped runtime if it is of type R.