DynRuntimeInitAttrs

Struct DynRuntimeInitAttrs 

pub struct DynRuntimeInitAttrs<T: UserEvent> { /* private fields */ }
The RuntimeInitAttrs of DynRuntime.

Wraps the attributes of the concrete runtime to use, which is how the runtime is selected. The default value selects no runtime, in which case initializing the DynRuntime fails with Error::RuntimeNotConfigured.

Implementations

Source

impl<T: UserEvent> DynRuntimeInitAttrs<T>

pub fn new<A: RuntimeInitAttrs<T>>(attrs: A) -> Self

Selects the runtime initialized with the given attributes.

pub fn is_configured(&self) -> bool

Whether a runtime was selected.