DynWindowOpener

Struct DynWindowOpener 

pub struct DynWindowOpener(/* private fields */);
Information about the webview that initiated a new window request, for the selected runtime.

Downcast it to the runtime’s opener type (e.g. tauri_runtime_wry::NewWindowOpener) to inspect it.

Implementations

Source

impl DynWindowOpener

pub fn new<O: Any + Send + Sync>(opener: O) -> Self

Wraps a runtime window opener.

pub fn is<O: Any>(&self) -> bool

Whether the inner opener is of type O.

pub fn downcast_ref<O: Any>(&self) -> Option<&O>

Returns a reference to the inner opener if it is of type O.

pub fn downcast<O: Any>(self) -> Result<O>

Unwraps the inner opener, failing if it is not of type O.