Struct tauri_runtime::menu::SystemTrayMenu [−][src]
#[non_exhaustive]pub struct SystemTrayMenu { pub items: Vec<SystemTrayMenuEntry>, }
This is supported on crate features
menu or system-tray only.Expand description
A system tray menu.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.items: Vec<SystemTrayMenuEntry>Implementations
Adds the custom menu item to the system tray menu.
Adds a native item to the system tray menu.
Adds an entry with submenu.