Trait tauri_runtime::Params [−][src]
pub trait Params: ParamsBase + 'static {
type Event: Tag;
type Label: Tag;
type MenuId: MenuId;
type SystemTrayMenuId: MenuId;
type Assets: Assets;
type Runtime: Runtime;
}Expand description
Types associated with the running Tauri application.
Associated Types
type Event: Tag[src]
The event type used to create and listen to events.
type Label: Tag[src]
The type used to determine the name of windows.
type MenuId: MenuId[src]
The type used to determine window menu ids.
type SystemTrayMenuId: MenuId[src]
The type used to determine system tray menu ids.
type Assets: Assets[src]
Assets that Tauri should serve from itself.
type Runtime: Runtime[src]
The underlying webview runtime used by the Tauri application.