Module webview

Module webview 

A layer between raw Runtime webviews and Tauri.

Structs

DetachedWebview
A webview that is not yet managed by Tauri.
InitializationScript
An initialization script
NewWindowFeatures
Window features of a window requested to open.
PendingWebview
A webview that has yet to be built.
WebContentProcessTermination
Details provided by the runtime when a web content process terminates.
WebviewAttributes
The attributes used to create an webview.

Enums

DownloadEvent
Download event.
NewWindowResponse
Response for the new window request handler.
PageLoadEvent
Kind of event for the page load handler.
PermissionKind
Permission types that can be requested by the webview.
PermissionResponse
Response for permission requests.
ScrollBarStyle
The scrollbar style to use in the webview.
WebContentProcessTerminationReason
Runtime-reported reason that a web content process stopped.

Functions

devtools_shortcut_scriptDebug-assertions enabled or devtools
The page script that binds the DevTools keyboard shortcut - Ctrl+Shift+I, or Cmd+Alt+I on macOS - to the webview plugin’s internal_toggle_devtools command.

Type Aliases

DocumentTitleChangedHandler
DownloadHandler
NavigationHandler
NewWindowHandler
OnPageLoadHandler
OnWebContentProcessTerminateHandler
UriSchemeProtocolHandler
WebResourceRequestHandler
WebviewIpcHandler
IPC handler.