NewWindowResponse

Enum NewWindowResponse 

pub enum NewWindowResponse {
    Allow,
    Create {
        window_id: WindowId,
    },
    Deny,
}
Response for the new window request handler.

Variants



Allow

Allow the window to be opened with the default implementation.



Create

Available on neither Android nor iOS.

Allow the window to be opened, with the given window.

The window must be created referencing the opener window so it can inherit the appropriate attributes.

Fields

window_id: WindowId


Deny

Deny the window from being opened.