NewWindowFeatures

Struct NewWindowFeatures 

pub struct NewWindowFeatures<T: UserEvent, R: Runtime<T>> { /* private fields */ }
Window features of a window requested to open.

Implementations

Source

impl<T: UserEvent, R: Runtime<T>> NewWindowFeatures<T, R>

pub fn new( size: Option<LogicalSize<f64>>, position: Option<LogicalPosition<f64>>, opener: R::WindowOpener, ) -> Self

pub fn size(&self) -> Option<LogicalSize<f64>>

Specifies the size of the content area as defined by the user’s operating system where the new window will be generated.

pub fn position(&self) -> Option<LogicalPosition<f64>>

Specifies the position of the window relative to the work area as defined by the user’s operating system where the new window will be generated.

pub fn opener(&self) -> &R::WindowOpener

Returns information about the webview that initiated a new window request.

pub fn into_opener(self) -> R::WindowOpener

Returns information about the webview that initiated a new window request.