Type-erased Runtime.
DynRuntime wraps any Runtime implementation behind trait objects so the concrete
runtime can be selected by the application when building it, instead of being part of the
generic parameters of every type that interacts with the runtime.
The concrete runtime is selected through DynRuntimeInitAttrs::new, which takes the
RuntimeInitAttrs of the runtime to use (e.g. tauri_runtime_wry::Wry::default()).
Runtime-specific APIs can still be reached by downcasting the wrappers
(see DynRuntimeHandle::downcast_ref, DynWebviewDispatcher::downcast_ref,
DynWindowDispatcher::downcast_ref and DynWebview::downcast_ref).
Structs
- DynEvent
Loop Proxy - The
EventLoopProxyofDynRuntime. - DynRuntime
- A type-erased
Runtime. - DynRuntime
Handle - The
RuntimeHandleofDynRuntime. - DynRuntime
Init Attrs - The
RuntimeInitAttrsofDynRuntime. - DynWebview
- The platform webview handle of the selected runtime, exposed through
WebviewDispatch::with_webview. - DynWebview
Attributes - The runtime-specific webview attributes of the selected runtime, see
Runtime::RuntimeWebviewAttributes. - DynWebview
Dispatcher - The
WebviewDispatchofDynRuntime. - DynWindow
Builder - A
WindowBuilderforDynRuntime. - DynWindow
Dispatcher - The
WindowDispatchofDynRuntime. - DynWindow
Opener - Information about the webview that initiated a new window request, for the selected runtime.