pub struct DynRuntime<T: UserEvent> { /* private fields */ }Expand description
A type-erased Runtime.
The concrete runtime is selected through its RuntimeInitAttrs,
see DynRuntimeInitAttrs::new.
Implementations
Sourceimpl<T: UserEvent> DynRuntime<T>
impl<T: UserEvent> DynRuntime<T>
Sourcepub fn from_runtime<R: Runtime<T>>(runtime: R) -> Self
pub fn from_runtime<R: Runtime<T>>(runtime: R) -> Self
Wraps an already initialized runtime.
Prefer Runtime::new with DynRuntimeInitAttrs to let the runtime be initialized with the
application’s RuntimeInitArgs; this is only useful for runtimes created by other means.
Sourcepub fn downcast_ref<R: Runtime<T>>(&self) -> Option<&R>
pub fn downcast_ref<R: Runtime<T>>(&self) -> Option<&R>
Returns a reference to the wrapped runtime if it is of type R.
Sourcepub fn downcast_mut<R: Runtime<T>>(&mut self) -> Option<&mut R>
pub fn downcast_mut<R: Runtime<T>>(&mut self) -> Option<&mut R>
Returns a mutable reference to the wrapped runtime if it is of type R.