pub struct DynRuntimeInitAttrs<T: UserEvent> { /* private fields */ }Expand description
The RuntimeInitAttrs of DynRuntime.
Wraps the attributes of the concrete runtime to use, which is how the runtime is selected.
The default value selects no runtime, in which case initializing the DynRuntime fails
with Error::RuntimeNotConfigured.
Implementations
Sourceimpl<T: UserEvent> DynRuntimeInitAttrs<T>
impl<T: UserEvent> DynRuntimeInitAttrs<T>
Sourcepub fn new<A: RuntimeInitAttrs<T>>(attrs: A) -> Self
pub fn new<A: RuntimeInitAttrs<T>>(attrs: A) -> Self
Selects the runtime initialized with the given attributes.
Sourcepub fn is_configured(&self) -> bool
pub fn is_configured(&self) -> bool
Whether a runtime was selected.