pub struct DynWebview(/* private fields */);Expand description
The platform webview handle of the selected runtime, exposed through WebviewDispatch::with_webview.
Downcast it to the runtime’s webview type (e.g. tauri_runtime_wry::Webview) to reach the platform APIs.
Implementations
Sourceimpl DynWebview
impl DynWebview
Sourcepub fn downcast_ref<W: Any>(&self) -> Option<&W>
pub fn downcast_ref<W: Any>(&self) -> Option<&W>
Returns a reference to the inner webview if it is of type W.
Sourcepub fn downcast_mut<W: Any>(&mut self) -> Option<&mut W>
pub fn downcast_mut<W: Any>(&mut self) -> Option<&mut W>
Returns a mutable reference to the inner webview if it is of type W.
Sourcepub fn into_inner(self) -> Box<dyn Any>
pub fn into_inner(self) -> Box<dyn Any>
Returns the inner boxed webview.