pub struct DynWebviewAttributes(/* private fields */);Expand description
The runtime-specific webview attributes of the selected runtime, see Runtime::RuntimeWebviewAttributes.
Holds the attributes type of the runtime in use (e.g. tauri_runtime_wry::WryWebviewAttributes)
once one of the runtime’s extension traits sets them through DynWebviewAttributes::get_or_default.
Until then the runtime uses its default attributes.
Implementations
Sourceimpl DynWebviewAttributes
impl DynWebviewAttributes
Sourcepub fn new<A: Any + Send + Sync>(attributes: A) -> Self
pub fn new<A: Any + Send + Sync>(attributes: A) -> Self
Wraps the attributes of the runtime in use.
Sourcepub fn downcast_ref<A: Any>(&self) -> Option<&A>
pub fn downcast_ref<A: Any>(&self) -> Option<&A>
Returns a reference to the attributes if they are of type A.