pub struct DynWindowOpener(/* private fields */);Expand description
Information about the webview that initiated a new window request, for the selected runtime.
Downcast it to the runtime’s opener type (e.g. tauri_runtime_wry::NewWindowOpener) to inspect it.
Implementations
Sourceimpl DynWindowOpener
impl DynWindowOpener
Sourcepub fn downcast_ref<O: Any>(&self) -> Option<&O>
pub fn downcast_ref<O: Any>(&self) -> Option<&O>
Returns a reference to the inner opener if it is of type O.