pub trait WebviewDispatch<T: UserEvent>:
Debug
+ Clone
+ Send
+ Sync
+ Sized
+ 'static {
type Runtime: Runtime<T>;
Show 31 methods
// Required methods
fn run_on_main_thread<F: FnOnce() + Send + 'static>(
&self,
f: F,
) -> Result<()>;
fn on_webview_event<F: Fn(&WebviewEvent) + Send + 'static>(
&self,
f: F,
) -> WebviewEventId;
fn with_webview<F: FnOnce(Box<dyn Any>) + Send + 'static>(
&self,
f: F,
) -> Result<()>;
fn open_devtools(&self);
fn close_devtools(&self);
fn is_devtools_open(&self) -> Result<bool>;
fn url(&self) -> Result<String>;
fn bounds(&self) -> Result<Rect>;
fn position(&self) -> Result<PhysicalPosition<i32>>;
fn size(&self) -> Result<PhysicalSize<u32>>;
fn navigate(&self, url: Url) -> Result<()>;
fn reload(&self) -> Result<()>;
fn print(&self) -> Result<()>;
fn close(&self) -> Result<()>;
fn set_bounds(&self, bounds: Rect) -> Result<()>;
fn set_size(&self, size: Size) -> Result<()>;
fn set_position(&self, position: Position) -> Result<()>;
fn set_focus(&self) -> Result<()>;
fn hide(&self) -> Result<()>;
fn show(&self) -> Result<()>;
fn eval_script<S: Into<String>>(&self, script: S) -> Result<()>;
fn eval_script_with_callback<S: Into<String>>(
&self,
script: S,
callback: impl Fn(String) + Send + 'static,
) -> Result<()>;
fn reparent(&self, window_id: WindowId) -> Result<()>;
fn cookies_for_url(&self, url: Url) -> Result<Vec<Cookie<'static>>>;
fn cookies(&self) -> Result<Vec<Cookie<'static>>>;
fn set_cookie(&self, cookie: Cookie<'_>) -> Result<()>;
fn delete_cookie(&self, cookie: Cookie<'_>) -> Result<()>;
fn set_auto_resize(&self, auto_resize: bool) -> Result<()>;
fn set_zoom(&self, scale_factor: f64) -> Result<()>;
fn set_background_color(&self, color: Option<Color>) -> Result<()>;
fn clear_all_browsing_data(&self) -> Result<()>;
}Expand description
Webview dispatcher. A thread-safe handle to the webview APIs.
Required Associated Types
Sourcetype Runtime: Runtime<T>
type Runtime: Runtime<T>
The runtime this WebviewDispatch runs under.
Required Methods
Sourcefn run_on_main_thread<F: FnOnce() + Send + 'static>(&self, f: F) -> Result<()>
fn run_on_main_thread<F: FnOnce() + Send + 'static>(&self, f: F) -> Result<()>
Run a task on the main thread.
Sourcefn on_webview_event<F: Fn(&WebviewEvent) + Send + 'static>(
&self,
f: F,
) -> WebviewEventId
fn on_webview_event<F: Fn(&WebviewEvent) + Send + 'static>( &self, f: F, ) -> WebviewEventId
Registers a webview event handler.
Sourcefn with_webview<F: FnOnce(Box<dyn Any>) + Send + 'static>(
&self,
f: F,
) -> Result<()>
fn with_webview<F: FnOnce(Box<dyn Any>) + Send + 'static>( &self, f: F, ) -> Result<()>
Runs a closure with the platform webview object as argument.
Sourcefn open_devtools(&self)
Available on debug-assertions enabled or crate feature devtools only.
fn open_devtools(&self)
devtools only.Open the web inspector which is usually called devtools.
Sourcefn close_devtools(&self)
Available on debug-assertions enabled or crate feature devtools only.
fn close_devtools(&self)
devtools only.Close the web inspector which is usually called devtools.
Sourcefn is_devtools_open(&self) -> Result<bool>
Available on debug-assertions enabled or crate feature devtools only.
fn is_devtools_open(&self) -> Result<bool>
devtools only.Gets the devtools window’s current open state.
Sourcefn position(&self) -> Result<PhysicalPosition<i32>>
fn position(&self) -> Result<PhysicalPosition<i32>>
Returns the position of the top-left hand corner of the webviews’s client area relative to the top-left hand corner of the window.
Sourcefn size(&self) -> Result<PhysicalSize<u32>>
fn size(&self) -> Result<PhysicalSize<u32>>
Returns the physical size of the webviews’s client area.
Navigate to the given URL.
Sourcefn set_bounds(&self, bounds: Rect) -> Result<()>
fn set_bounds(&self, bounds: Rect) -> Result<()>
Sets the webview’s bounds.
Sourcefn set_position(&self, position: Position) -> Result<()>
fn set_position(&self, position: Position) -> Result<()>
Updates the webview position.
Sourcefn eval_script<S: Into<String>>(&self, script: S) -> Result<()>
fn eval_script<S: Into<String>>(&self, script: S) -> Result<()>
Executes javascript on the window this WindowDispatch represents.
Sourcefn eval_script_with_callback<S: Into<String>>(
&self,
script: S,
callback: impl Fn(String) + Send + 'static,
) -> Result<()>
fn eval_script_with_callback<S: Into<String>>( &self, script: S, callback: impl Fn(String) + Send + 'static, ) -> Result<()>
Evaluate JavaScript with callback function on the webview this WebviewDispatch represents.
The evaluation result will be serialized into a JSON string and passed to the callback function.
Exception is ignored because of the limitation on Windows. You can catch it yourself and return as string as a workaround.
Return all cookies in the cookie store.
Stability
The return value of this function leverages cookie::Cookie which re-exports the cookie crate.
This dependency might receive updates in minor Tauri releases.
Sourcefn set_auto_resize(&self, auto_resize: bool) -> Result<()>
fn set_auto_resize(&self, auto_resize: bool) -> Result<()>
Sets whether the webview should automatically grow and shrink its size and position when the parent window resizes.
Sourcefn clear_all_browsing_data(&self) -> Result<()>
fn clear_all_browsing_data(&self) -> Result<()>
Clear all browsing data for this webview.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".