A layer between raw Runtime webviews and Tauri.
Structs
- Detached
Webview - A webview that is not yet managed by Tauri.
- Initialization
Script - An initialization script
- NewWindow
Features - Window features of a window requested to open.
- Pending
Webview - A webview that has yet to be built.
- WebContent
Process Termination - Details provided by the runtime when a web content process terminates.
- Webview
Attributes - The attributes used to create an webview.
Enums
- Download
Event - Download event.
- NewWindow
Response - Response for the new window request handler.
- Page
Load Event - Kind of event for the page load handler.
- Permission
Kind - Permission types that can be requested by the webview.
- Permission
Response - Response for permission requests.
- Scroll
BarStyle - The scrollbar style to use in the webview.
- WebContent
Process Termination Reason - Runtime-reported reason that a web content process stopped.
Functions
- devtools_
shortcut_ script Debug-assertions enabled or devtools - The page script that binds the DevTools keyboard shortcut - Ctrl+Shift+I, or
Cmd+Alt+I on macOS - to the
webviewplugin’sinternal_toggle_devtoolscommand.