Module webview

Module webview 

A layer between raw Runtime webviews and Tauri.

Structs

DetachedWebview
A webview that is not yet managed by Tauri.
InitializationScript
An initialization script
NewWindowFeatures
Window features of a window requested to open.
NewWindowOpener
Information about the webview that initiated a new window request.
PendingWebview
A webview that has yet to be built.
WebviewAttributes
The attributes used to create an webview.

Enums

DownloadEvent
Download event.
NewWindowResponse
Response for the new window request handler.
PageLoadEvent
Kind of event for the page load handler.
PermissionKind
Permission types that can be requested by the webview.
PermissionResponse
Response for permission requests.
ScrollBarStyle
The scrollbar style to use in the webview.

Type Aliases

WebviewIpcHandler
IPC handler.