pub struct NewWindowFeatures<T: UserEvent, R: Runtime<T>> { /* private fields */ }Expand description
Window features of a window requested to open.
Implementations
Sourceimpl<T: UserEvent, R: Runtime<T>> NewWindowFeatures<T, R>
impl<T: UserEvent, R: Runtime<T>> NewWindowFeatures<T, R>
pub fn new( size: Option<LogicalSize<f64>>, position: Option<LogicalPosition<f64>>, opener: R::WindowOpener, ) -> Self
Sourcepub fn size(&self) -> Option<LogicalSize<f64>>
pub fn size(&self) -> Option<LogicalSize<f64>>
Specifies the size of the content area as defined by the user’s operating system where the new window will be generated.
Sourcepub fn position(&self) -> Option<LogicalPosition<f64>>
pub fn position(&self) -> Option<LogicalPosition<f64>>
Specifies the position of the window relative to the work area as defined by the user’s operating system where the new window will be generated.
Sourcepub fn opener(&self) -> &R::WindowOpener
pub fn opener(&self) -> &R::WindowOpener
Returns information about the webview that initiated a new window request.
Sourcepub fn into_opener(self) -> R::WindowOpener
pub fn into_opener(self) -> R::WindowOpener
Returns information about the webview that initiated a new window request.