Module tauri_runtime::window [−][src]
A layer between raw Runtime webview windows and Tauri.
Modules
| dpi | UI scaling utilities. |
Structs
| DetachedWindow | A webview window that is not yet managed by Tauri. |
| MenuEvent | A menu event. |
| PendingWindow | A webview window that has yet to be built. |
Enums
| WindowEvent | An event from a window. |